@@ -635,7 +635,7 @@ render_display_name (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 
 	display = name;
 
-	if (!strcmp ("invitations", folder_type)) {
+	if (folder_type && !strcmp ("invitations", folder_type)) {
 		/* check unread count for invitation list */
 		SunOneInvitationListModel *model;
 
